==> CallApiCPlusPlus-0.2.1.zip: CallApiCPlusPlus-0.2.1/src/audiocallmanager.h <==
/**
 * SPDX-FileCopyrightText: 2024 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: BSD-3-Clause
 */

#pragma once

#include <QObject>
#include <QQuickItem>
#include <QVariantMap>

#include <audiocontext.h>
#include <callmanager.h>

#include "audiomanager.h"

using ru::auroraos::call::AudioContext;
using ru::auroraos::call::Call;
using ru::auroraos::call::CallManager;

class AudioCall;

class AudioCallManager : public CallManager
{
    Q_OBJECT

    Q_PROPERTY(bool holdable READ holdable WRITE setHoldable NOTIFY holdableChanged)
    Q_PROPERTY(bool redialable READ redialable WRITE setRedialable NOTIFY redialableChanged)
    Q_PROPERTY(AudioManager* audioManager READ audioManager CONSTANT)
    Q_PROPERTY(QString audioGeneratorConfigPath READ audioGeneratorConfigPath CONSTANT)

public:
    explicit AudioCallManager(const QString &accountId, QObject *parent = nullptr);
    ~AudioCallManager() = default;

    Q_INVOKABLE AudioCall *getAudioCall(const QString &callId) const;
    Q_INVOKABLE Call *initiateCall(const QVariantMap &properties);
    Q_INVOKABLE Call *reportIncomingCall(const QVariantMap &properties);
    Q_INVOKABLE void disconnectAll();

    bool holdable() const;
    void setHoldable(bool on);

    bool redialable() const;
    void setRedialable(bool on);

    AudioManager *audioManager()
    {
        return &m_audioManager;
    }

    QString audioGeneratorConfigPath() const;

public slots:
    void openUri(const QString &uri);

signals:
    void holdableChanged(bool on);
    void redialableChanged(bool on);

private:
    Call *newCall(QVariantMap &properties);

private:
    AudioContext m_audioContext;
    AudioManager m_audioManager;
    unsigned int m_callId;
    bool m_holdable;
    bool m_redialable;
};

QML_DECLARE_TYPE(AudioCallManager)

==> CallApiCPlusPlus-0.2.3.zip: CallApiCPlusPlus-0.2.3/src/audiocallmanager.h <==
/**
 * SPDX-FileCopyrightText: 2024 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: BSD-3-Clause
 */

#pragma once

#include <QObject>
#include <QQuickItem>
#include <QVariantMap>

#include <audiocontext.h>
#include <callmanager.h>

#include "audiomanager.h"

using ru::auroraos::call::AudioContext;
using ru::auroraos::call::Call;
using ru::auroraos::call::CallManager;

class AudioCall;

class AudioCallManager : public CallManager
{
    Q_OBJECT

    Q_PROPERTY(bool holdable READ holdable WRITE setHoldable NOTIFY holdableChanged)
    Q_PROPERTY(bool redialable READ redialable WRITE setRedialable NOTIFY redialableChanged)
    Q_PROPERTY(AudioManager* audioManager READ audioManager CONSTANT)
    Q_PROPERTY(QString audioGeneratorConfigPath READ audioGeneratorConfigPath CONSTANT)
    Q_PROPERTY(QString useCallIconConfigPath READ useCallIconConfigPath CONSTANT)

public:
    explicit AudioCallManager(const QString &accountId, QObject *parent = nullptr);
    ~AudioCallManager() = default;

    Q_INVOKABLE AudioCall *getAudioCall(const QString &callId) const;
    Q_INVOKABLE Call *initiateCall(const QVariantMap &properties);
    Q_INVOKABLE Call *reportIncomingCall(const QVariantMap &properties);
    Q_INVOKABLE void disconnectAll();

    bool holdable() const;
    void setHoldable(bool on);

    bool redialable() const;
    void setRedialable(bool on);

    AudioManager *audioManager()
    {
        return &m_audioManager;
    }

    QString audioGeneratorConfigPath() const;
    QString useCallIconConfigPath() const;

public slots:
    void openUri(const QString &uri);

signals:
    void holdableChanged(bool on);
    void redialableChanged(bool on);

private:
    Call *newCall(QVariantMap &properties);

private:
    AudioContext m_audioContext;
    AudioManager m_audioManager;
    unsigned int m_callId;
    bool m_holdable;
    bool m_redialable;
};

QML_DECLARE_TYPE(AudioCallManager)
